Sencha - Ext JS - Amazing Web Apps Built on Web Standards

# Welcome to Extensible

Thank you for downloading Extensible + Ext Calendar Pro — Professional strength components for Ext JS.

View Demos

## Learn

- Try out our interactive demos with full source comments
- Browse our extensive API documentation
- For advanced, hands-on support, please see our premium support subscriptions

## Engage

Our community forums are a great place to ask questions and interact with other Extensible developers.

Visit Extensible Forum

- Follow @Ext_ensible on Twitter
- Become a fan on Facebook
- Read the official blog
- Subscribe to our email newsletter

## License

Extensible is dual-licensed commercial + GPL, just like Ext JS. This means:

- Free to use and test in your local development environment
- Free to use in your open source projects
- Purchase a developer license if you don’t plan on releasing your website or application’s code as open source

To purchase a commercial license, please visit our store page.